%bcond_with bootstrap
%bcond_without java

%define pkidir %{_sysconfdir}/pki
%define catrustdir %{_sysconfdir}/pki/ca-trust
%define classic_tls_bundle ca-bundle.crt
%define openssl_format_trust_bundle ca-bundle.trust.crt
%define p11_format_bundle ca-bundle.trust.p11-kit
%define legacy_default_bundle ca-bundle.legacy.default.crt
%define legacy_disable_bundle ca-bundle.legacy.disable.crt
%define java_bundle java/cacerts

Summary:	Bundle of CA Root Certificates
Name:		rootcerts
Epoch:		1
# *** Important:  update BOTH Source0 and Source1 when newer than date below
Version:	20250424.00
Release:	%mkrel 1
License:	GPL
Group:		Security
URL:		https://www.mageia.org
# For Source0, the NSS commit trunk version of this file is here:
# https://hg.mozilla.org/projects/nss/raw-file/default/lib/ckfw/builtins/certdata.txt
# See https://hg.mozilla.org/projects/nss/log/default/lib/ckfw/builtins/certdata.txt for new versions
# The version tag for this package should come from the commit date of the version used from the NSS repository above
# To choose which NSS commit version to use, we can check the certdata.txt file used in either...
# the current Mozilla release:
# https://hg.mozilla.org/releases/mozilla-release/log/default/security/nss/lib/ckfw/builtins/certdata.txt
# or the Mozilla development commit trunk:
# https://hg.mozilla.org/mozilla-central/log/default/security/nss/lib/ckfw/builtins/certdata.txt
# Ideally, it should correspond to the version shipped in the NSS release we are using
Source0:	certdata-%{version}.txt
# Similarly, Source1 comes from:
# https://hg.mozilla.org/projects/nss/raw-file/default/lib/ckfw/builtins/nssckbi.h
# Check the log to see if it needs to be updated:
# https://hg.mozilla.org/projects/nss/log/default/lib/ckfw/builtins/nssckbi.h
Source1:	nssckbi.h
Source2:	update-ca-trust
Source3:	trust-fixes
Source4:	certdata2pem.py
Source5:	ca-legacy.conf
Source6:	ca-legacy
Source9:	ca-legacy.8.txt
Source10:	update-ca-trust.8.txt
Requires(post):	coreutils
Requires(post):	p11-kit
Requires(post):	p11-kit-trust
BuildRequires:	perl
BuildRequires:	openssl
%if %{without bootstrap}
BuildRequires:	nss
%endif
%if %with java
BuildRequires:	javapackages-tools
BuildRequires:	java-devel
%endif
BuildRequires:	asciidoc
BuildRequires:	xsltproc 

BuildArch:	noarch
Provides:	ca-certificates

%description
This is a bundle of X.509 certificates of public Certificate
Authorities (CA). These were automatically extracted from Mozilla's
root CA list (the file "certdata.txt"). It contains the certificates
in both plain text and PEM format and therefore can be directly used
with an Apache/mod_ssl webserver for SSL client authentication. Just
configure this file as the SSLCACertificateFile.

%if %with java
%package java
Summary:	Bundle of CA Root Certificates for Java
Group:		Development/Java

%description java
Bundle of X.509 certificates of public Certificate Authorities (CA)
in a format used by Java Runtime Environment.
%endif

%prep
rm -rf %{name}
mkdir -p %{name}/certs/legacy-default
mkdir %{name}/certs/legacy-disable
mkdir %{name}/java


%build
pushd %{name}/certs
 cp %{SOURCE0} certdata.txt
 python3 %{SOURCE4} >c2p.log 2>c2p.err
popd
pushd %{name}
 (
   cat <<EOF
# This is a bundle of X.509 certificates of public Certificate
# Authorities.  It was generated from the Mozilla root CA list.
# These certificates and trust/distrust attributes use the file format accepted
# by the p11-kit-trust module.
#
# Source: nss/lib/ckfw/builtins/certdata.txt
# Source: nss/lib/ckfw/builtins/nssckbi.h
#
# Generated from:
EOF
   cat %{SOURCE1}  |grep -w NSS_BUILTINS_LIBRARY_VERSION | awk '{print "# " $2 " " $3}';
   echo '#';
 ) > %{p11_format_bundle}

 touch %{legacy_default_bundle}
 NUM_LEGACY_DEFAULT=`find certs/legacy-default -type f | wc -l`
 if [ $NUM_LEGACY_DEFAULT -ne 0 ]; then
     for f in certs/legacy-default/*.crt; do 
       echo "processing $f"
       tbits=`sed -n '/^# openssl-trust/{s/^.*=//;p;}' $f`
       alias=`sed -n '/^# alias=/{s/^.*=//;p;q;}' $f | sed "s/'//g" | sed 's/"//g'`
       targs=""
       if [ -n "$tbits" ]; then
          for t in $tbits; do
             targs="${targs} -addtrust $t"
          done
       fi
       if [ -n "$targs" ]; then
          echo "legacy default flags $targs for $f" >> info.trust
          openssl x509 -text -in "$f" -trustout $targs -setalias "$alias" >> %{legacy_default_bundle}
       fi
     done
 fi

 touch %{legacy_disable_bundle}
 NUM_LEGACY_DISABLE=`find certs/legacy-disable -type f | wc -l`
 if [ $NUM_LEGACY_DISABLE -ne 0 ]; then
     for f in certs/legacy-disable/*.crt; do 
       echo "processing $f"
       tbits=`sed -n '/^# openssl-trust/{s/^.*=//;p;}' $f`
       alias=`sed -n '/^# alias=/{s/^.*=//;p;q;}' $f | sed "s/'//g" | sed 's/"//g'`
       targs=""
       if [ -n "$tbits" ]; then
          for t in $tbits; do
             targs="${targs} -addtrust $t"
          done
       fi
       if [ -n "$targs" ]; then
          echo "legacy disable flags $targs for $f" >> info.trust
          openssl x509 -text -in "$f" -trustout $targs -setalias "$alias" >> %{legacy_disable_bundle}
       fi
     done
 fi

 P11FILES=`find certs -name \*.tmp-p11-kit | wc -l`
 if [ $P11FILES -ne 0 ]; then
   for p in certs/*.tmp-p11-kit; do 
     cat "$p" >> %{p11_format_bundle}
   done
 fi
 # Append our trust fixes
 cat %{SOURCE3} >> %{p11_format_bundle}
popd

#manpage
cp %{SOURCE10} %{name}/update-ca-trust.8.txt
asciidoc.py -v -d manpage -b docbook %{name}/update-ca-trust.8.txt
xsltproc --nonet -o %{name}/update-ca-trust.8 /etc/asciidoc/docbook-xsl/manpage.xsl %{name}/update-ca-trust.8.xml

cp %{SOURCE9} %{name}/ca-legacy.8.txt
asciidoc.py -v -d manpage -b docbook %{name}/ca-legacy.8.txt
xsltproc --nonet -o %{name}/ca-legacy.8 /etc/asciidoc/docbook-xsl/manpage.xsl %{name}/ca-legacy.8.xml


%install
mkdir -p -m 755 %{buildroot}%{pkidir}/java
mkdir -p -m 755 %{buildroot}%{catrustdir}/source
mkdir -p -m 755 %{buildroot}%{catrustdir}/source/anchors
mkdir -p -m 755 %{buildroot}%{catrustdir}/source/blacklist
mkdir -p -m 755 %{buildroot}%{catrustdir}/extracted
mkdir -p -m 755 %{buildroot}%{catrustdir}/extracted/pem
mkdir -p -m 755 %{buildroot}%{catrustdir}/extracted/openssl
mkdir -p -m 755 %{buildroot}%{catrustdir}/extracted/java
mkdir -p -m 755 %{buildroot}%{catrustdir}/extracted/edk2
mkdir -p -m 755 %{buildroot}%{_mandir}/man8
install -p -m 644 %{name}/update-ca-trust.8 %{buildroot}%{_mandir}/man8
install -p -m 644 %{name}/ca-legacy.8 %{buildroot}%{_mandir}/man8
install -d %{buildroot}%{_sysconfdir}/pki/tls/certs
install -d %{buildroot}%{_sysconfdir}/pki/tls/certs/source
install -d %{buildroot}%{_sysconfdir}/pki/tls/mozilla
install -d %{buildroot}%{_bindir}
install -p -m 644 %{SOURCE5} %{buildroot}%{catrustdir}/ca-legacy.conf
install -p -m 755 %{SOURCE2} %{buildroot}%{_bindir}/update-ca-trust
install -p -m 755 %{SOURCE6} %{buildroot}%{_bindir}/ca-legacy

install -m0644 %{name}/certs/certdata.txt %{buildroot}%{_sysconfdir}/pki/tls/mozilla/

mkdir -p -m 755 %{buildroot}%{catrustdir}/source
mkdir -p -m 755 %{buildroot}%{_datadir}/pki/ca-trust-source
install -p -m 644 %{name}/%{p11_format_bundle} %{buildroot}%{_datadir}/pki/ca-trust-source/%{p11_format_bundle}

mkdir -p -m 755 %{buildroot}%{_datadir}/pki/ca-trust-legacy
install -p -m 644 %{name}/%{legacy_default_bundle} %{buildroot}%{_datadir}/pki/ca-trust-legacy/%{legacy_default_bundle}
install -p -m 644 %{name}/%{legacy_disable_bundle} %{buildroot}%{_datadir}/pki/ca-trust-legacy/%{legacy_disable_bundle}

%if %with java
install -d %{buildroot}%{_sysconfdir}/pki/java
%endif

cat > README << EOF

R O O T C E R T S
-----------------

This is a bundle of X.509 certificates of public Certificate
Authorities (CA). These were automatically extracted from Mozilla's
root CA list (the file "certdata.txt"). It contains the certificates
in both plain text and PEM format and therefore can be directly used
with an Apache/mod_ssl webserver for SSL client authentication. Just
configure this file as the SSLCACertificateFile.

EOF

# be compatible with Debian/Ubuntu SSL paths
# fix #58107 (also used by dovecot default config)
install -d %{buildroot}%{_sysconfdir}/ssl
for d in certs private; do
    ln -sf %{_sysconfdir}/pki/tls/$d %{buildroot}%{_sysconfdir}/ssl/
done

# touch ghosted files that will be extracted dynamically
# Set chmod 444 to use identical permission
touch %{buildroot}%{catrustdir}/extracted/pem/tls-ca-bundle.pem
chmod 444 %{buildroot}%{catrustdir}/extracted/pem/tls-ca-bundle.pem
touch %{buildroot}%{catrustdir}/extracted/pem/email-ca-bundle.pem
chmod 444 %{buildroot}%{catrustdir}/extracted/pem/email-ca-bundle.pem
touch %{buildroot}%{catrustdir}/extracted/pem/objsign-ca-bundle.pem
chmod 444 %{buildroot}%{catrustdir}/extracted/pem/objsign-ca-bundle.pem
touch %{buildroot}%{catrustdir}/extracted/openssl/%{openssl_format_trust_bundle}
chmod 444 %{buildroot}%{catrustdir}/extracted/openssl/%{openssl_format_trust_bundle}
touch %{buildroot}%{catrustdir}/extracted/%{java_bundle}
chmod 444 %{buildroot}%{catrustdir}/extracted/%{java_bundle}
touch %{buildroot}%{catrustdir}/extracted/edk2/cacerts.bin
chmod 444 %{buildroot}%{catrustdir}/extracted/edk2/cacerts.bin

# legacy filenames
ln -s %{catrustdir}/extracted/pem/tls-ca-bundle.pem \
    %{buildroot}%{pkidir}/tls/cert.pem
ln -s %{catrustdir}/extracted/pem/tls-ca-bundle.pem \
    %{buildroot}%{pkidir}/tls/certs/%{classic_tls_bundle}
ln -s %{catrustdir}/extracted/openssl/%{openssl_format_trust_bundle} \
    %{buildroot}%{pkidir}/tls/certs/%{openssl_format_trust_bundle}
ln -s %{catrustdir}/extracted/%{java_bundle} \
    %{buildroot}%{pkidir}/%{java_bundle}

%post
if [ -x %{_bindir}/ln ]; then
%{_bindir}/ca-legacy install
%{_bindir}/update-ca-trust
fi

%posttrans
%{_bindir}/ca-legacy install
%{_bindir}/update-ca-trust

%files 
%doc README 
%dir %{catrustdir}
%dir %{catrustdir}/source
%dir %{catrustdir}/source/anchors
%dir %{catrustdir}/source/blacklist
%{_sysconfdir}/pki/tls/cert.pem
%{_mandir}/man8/ca-legacy.8.*
%{_mandir}/man8/update-ca-trust.8.*
%config(noreplace) %{_sysconfdir}/pki/tls/mozilla/certdata.txt
%{_sysconfdir}/ssl/certs
%{_sysconfdir}/ssl/private
# symlinks for old locations
%{pkidir}/tls/certs/%{classic_tls_bundle}
%{pkidir}/tls/certs/%{openssl_format_trust_bundle}
# master bundle file with trust
%{_datadir}/pki/ca-trust-source/%{p11_format_bundle}

%{_datadir}/pki/ca-trust-legacy/%{legacy_default_bundle}
%{_datadir}/pki/ca-trust-legacy/%{legacy_disable_bundle}
# update/extract tool
%config(noreplace) %{catrustdir}/ca-legacy.conf
%{_bindir}/update-ca-trust
%{_bindir}/ca-legacy
%ghost %{catrustdir}/source/ca-bundle.legacy.crt
# files extracted files
%dir %{catrustdir}/extracted/
%dir %{catrustdir}/extracted/pem/
%ghost %{catrustdir}/extracted/pem/tls-ca-bundle.pem
%ghost %{catrustdir}/extracted/pem/email-ca-bundle.pem
%ghost %{catrustdir}/extracted/pem/objsign-ca-bundle.pem
%dir %{catrustdir}/extracted/openssl/
%ghost %{catrustdir}/extracted/openssl/%{openssl_format_trust_bundle}
%dir %{catrustdir}/extracted/java/
%ghost %{catrustdir}/extracted/%{java_bundle}
%dir %{catrustdir}/extracted/edk2/
%ghost %{catrustdir}/extracted/edk2/cacerts.bin

%if %with java
%files java
%dir %{_sysconfdir}/pki/java
%config(noreplace) %{_sysconfdir}/pki/java/cacerts
%endif


%changelog
* Mon May 19 2025 ns80 <ns80> 1:20250424.00-1.mga9
+ Revision: 2184813
- new certdata.txt file as of 2025-04-24 (mga#34287)
- new certdata.txt file as of 2025-01-30 (mga#33983)
- new certdata.txt file as of 2024-11-19 (mga#33804)
- new certdata.txt file as of 2024-08-23 (mga#33501)
- new certdata.txt file as of 2024-02-15 (mga#32876)
- new certdata.txt file as of 2023-11-16 (mga#32551)
- new certdata.txt file as of 2023-07-20 (mga#32207)

* Tue May 09 2023 luigiwalser <luigiwalser> 1:20230505.00-1.mga9
+ Revision: 1956339
- new certdata.txt file as of 2023-05-05

* Tue Dec 06 2022 luigiwalser <luigiwalser> 1:20221130.00-1.mga9
+ Revision: 1918640
- new certdata.txt file as of 2022-11-30
- new nssckbi.h file as of 2022-11-29

* Mon Sep 19 2022 luigiwalser <luigiwalser> 1:20220907.00-1.mga9
+ Revision: 1890585
- new certdata.txt file as of 2022-09-07
- new nssckbi.h file as of 2022-09-07

* Tue Sep 13 2022 wally <wally> 1:20220610.00-3.mga9
+ Revision: 1887572
- own also /etc/pki/ca-trust

* Tue Sep 13 2022 wally <wally> 1:20220610.00-2.mga9
+ Revision: 1887561
- own /etc/pki/ca-trust/extracted/ and its subdirs

* Mon Jun 27 2022 luigiwalser <luigiwalser> 1:20220610.00-1.mga9
+ Revision: 1866438
- new certdata.txt file as of 2022-06-10
- new nssckbi.h file as of 2022-06-10

* Tue Apr 05 2022 luigiwalser <luigiwalser> 1:20220324.00-1.mga9
+ Revision: 1845240
- new certdata.txt file as of 2022-03-24

* Sat Mar 26 2022 umeabot <umeabot> 1:20220208.00-2.mga9
+ Revision: 1828641
- Mageia 9 Mass Rebuild

* Sat Mar 05 2022 luigiwalser <luigiwalser> 1:20220208.00-1.mga9
+ Revision: 1789113
- new certdata.txt file as of 2022-02-08

* Tue Jan 11 2022 luigiwalser <luigiwalser> 1:20211213.00-1.mga9
+ Revision: 1767874
- new certdata.txt file as of 2021-12-13
- new nssckbi.h file as of 2021-12-13

* Mon Oct 04 2021 luigiwalser <luigiwalser> 1:20210907.00-1.mga9
+ Revision: 1749361
- new certdata.txt file as of 2021-09-07
- new nssckbi.h file as of 2021-09-16

* Mon Jun 28 2021 luigiwalser <luigiwalser> 1:20210525.00-2.mga9
+ Revision: 1734093
- new nssckbi.h file as of 2021-06-10

* Mon May 31 2021 luigiwalser <luigiwalser> 1:20210525.00-1.mga9
+ Revision: 1729033
- new certdata.txt file as of 2021-05-25

* Sat Feb 27 2021 luigiwalser <luigiwalser> 1:20210223.00-1.mga9
+ Revision: 1692492
- new certdata.txt file as of 2021-02-23
- new nssckbi.h file as of 2021-02-23

* Wed Dec 02 2020 luigiwalser <luigiwalser> 1:20201201.00-2.mga8
+ Revision: 1651703
- new nssckbi.h file as of 2020-12-01

* Wed Dec 02 2020 luigiwalser <luigiwalser> 1:20201201.00-1.mga8
+ Revision: 1651701
- new certdata.txt file as of 2020-12-01

* Wed Oct 21 2020 luigiwalser <luigiwalser> 1:20201021.00-1.mga8
+ Revision: 1637842
- new certdata.txt file as of 2020-10-21

* Mon Sep 21 2020 luigiwalser <luigiwalser> 1:20200911.00-1.mga8
+ Revision: 1629352
- new certdata.txt file as of 2020-09-11
- new nssckbi.h file as of 2020-09-11

* Mon Sep 07 2020 luigiwalser <luigiwalser> 1:20200612.00-2.mga8
+ Revision: 1623358
- post scriplet depends on ln, re-run in posttrans (from fedora)

* Thu Jun 18 2020 luigiwalser <luigiwalser> 1:20200612.00-1.mga8
+ Revision: 1596522
- new certdata.txt file as of 2020-06-12
- new nssckbi.h file as of 2020-06-15

* Thu Jun 11 2020 martinw <martinw> 1:20200527.00-4.mga8
+ Revision: 1592661
- add missing require (p11-kit-trust) for post-install script

* Thu Jun 11 2020 martinw <martinw> 1:20200527.00-3.mga8
+ Revision: 1592611
- add missing requires for post-install script

* Thu Jun 11 2020 ovitters <ovitters> 1:20200527.00-2.mga8
+ Revision: 1592547
- apply changes by Thierry Vignaud and Fedora

* Mon Jun 01 2020 luigiwalser <luigiwalser> 1:20200527.00-1.mga8
+ Revision: 1589476
- new certdata.txt file as of 2020-05-27

* Tue May 05 2020 luigiwalser <luigiwalser> 1:20191126.00-3.mga8
+ Revision: 1580618
- remove code dealing with removed cert
- disable cacert for mga8+
- remove ancient expired extra root certs
- update cacert.org root cert

* Tue Feb 18 2020 umeabot <umeabot> 1:20191126.00-2.mga8
+ Revision: 1539200
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Nov 30 2019 luigiwalser <luigiwalser> 1:20191126.00-1.mga8
+ Revision: 1463833
- new certdata.txt file as of 2019-11-26

* Tue Oct 22 2019 luigiwalser <luigiwalser> 1:20191011.00-1.mga8
+ Revision: 1455146
- new certdata.txt file as of 2019-10-11

* Mon Aug 26 2019 luigiwalser <luigiwalser> 1:20190820.00-1.mga8
+ Revision: 1432372
- new certdata.txt file as of 2019-08-20

* Thu Jul 11 2019 luigiwalser <luigiwalser> 1:20190604.00-1.mga8
+ Revision: 1420038
- new certdata.txt file as of 2019-06-04

* Tue Mar 19 2019 luigiwalser <luigiwalser> 1:20190306.00-1.mga7
+ Revision: 1378813
- new certdata.txt file as of 2019-03-06

* Sat Dec 08 2018 luigiwalser <luigiwalser> 1:20181108.00-1.mga7
+ Revision: 1338980
- new certdata.txt file as of 2018-11-08

* Mon Oct 15 2018 luigiwalser <luigiwalser> 1:20181001.00-1.mga7
+ Revision: 1320649
- new certdata.txt file as of 2018-10-01

* Fri Sep 21 2018 umeabot <umeabot> 1:20180411.00-2.mga7
+ Revision: 1290771
- Mageia 7 Mass Rebuild

* Sun May 13 2018 wally <wally> 1:20180411.00-1.mga7
+ Revision: 1228730
- add patch to build with 'openssl rehash' instead of 'c_rehash'
+ luigiwalser <luigiwalser>
- new certdata.txt file as of 2018-04-11

* Sat Jan 20 2018 luigiwalser <luigiwalser> 1:20180104.00-1.mga7
+ Revision: 1195139
- new certdata.txt file as of 2018-01-04

* Wed Dec 13 2017 luigiwalser <luigiwalser> 1:20171122.00-1.mga7
+ Revision: 1182474
- new certdata.txt file as of 2017-11-22

* Tue Nov 14 2017 luigiwalser <luigiwalser> 1:20171025.00-1.mga7
+ Revision: 1177324
- new certdata.txt file as of 2017-10-25
- remove patch no longer needed with new nss

* Sun Oct 29 2017 wally <wally> 1:20170718.00-2.mga7
+ Revision: 1174517
- provide ca-certificates to make google-chrome installable

* Tue Aug 22 2017 sander85 <sander85> 1:20170718.00-1.mga7
+ Revision: 1142897
- Fix build with new openssl
+ luigiwalser <luigiwalser>
- new certdata.txt file as of 2017-07-18

* Fri Apr 21 2017 luigiwalser <luigiwalser> 1:20170404.00-1.mga6
+ Revision: 1097021
- new certdata.txt file as of 2017-04-04

* Wed Mar 08 2017 mrambo3501 <mrambo3501> 1:20170209.00-2.mga6
+ Revision: 1089962
- add patch to revert attributes not supported by current nss

* Sat Mar 04 2017 luigiwalser <luigiwalser> 1:20170209.00-1.mga6
+ Revision: 1088737
- new certdata.txt file as of 2017-02-09

* Sun Jan 15 2017 luigiwalser <luigiwalser> 1:20170102.00-1.mga6
+ Revision: 1081752
- new certdata.txt file as of 2017-01-02

* Tue Oct 04 2016 luigiwalser <luigiwalser> 1:20160922.00-1.mga6
+ Revision: 1058740
- new certdata.txt file as of 2016-09-22

* Tue Sep 20 2016 luigiwalser <luigiwalser> 1:20160826.00-1.mga6
+ Revision: 1054564
- new certdata.txt file as of 2016-08-26

* Fri Aug 05 2016 luigiwalser <luigiwalser> 1:20160805.00-1.mga6
+ Revision: 1044667
- new certdata.txt file as of 2016-08-05

* Mon Jul 25 2016 luigiwalser <luigiwalser> 1:20160610.00-1.mga6
+ Revision: 1043619
- new certdata.txt file as of 2016-06-10

* Thu Jun 16 2016 daviddavid <daviddavid> 1:20160225.00-3.mga6
+ Revision: 1021791
- add missing BR on openssl-perl

* Sat Apr 09 2016 pterjan <pterjan> 1:20160225.00-2.mga6
+ Revision: 999930
- Make this package noarch, it's only data in /etc

* Sat Mar 12 2016 luigiwalser <luigiwalser> 1:20160225.00-1.mga6
+ Revision: 989574
- new certdata.txt file as of 2016-02-25
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sat Dec 05 2015 neoclust <neoclust> 1:20151029.00-2.mga6
+ Revision: 908468
- Enable java build on ARM

* Sun Nov 01 2015 luigiwalser <luigiwalser> 1:20151029.00-1.mga6
+ Revision: 897238
- new certdata.txt file as of 2015-10-29

* Fri Aug 07 2015 luigiwalser <luigiwalser> 1:20150709.00-1.mga6
+ Revision: 861553
- new certdata.txt file as of 2015-07-09

* Wed May 06 2015 luigiwalser <luigiwalser> 1:20150420.00-1.mga5
+ Revision: 821335
- new certdata.txt file as of 2015-04-20

* Wed Apr 01 2015 luigiwalser <luigiwalser> 1:20150326.00-1.mga5
+ Revision: 819491
- new certdata.txt file as of 2015-03-26

* Mon Mar 23 2015 luigiwalser <luigiwalser> 1:20150226.00-1.mga5
+ Revision: 819109
- new certdata.txt file as of 2015-02-26

* Tue Dec 02 2014 luigiwalser <luigiwalser> 1:20141117.00-1.mga5
+ Revision: 800260
- new certdata.txt file as of 2014-11-17

* Wed Oct 15 2014 umeabot <umeabot> 1:20140805.00-3.mga5
+ Revision: 739158
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:20140805.00-2.mga5
+ Revision: 688693
- Mageia 5 Mass Rebuild

* Sun Aug 17 2014 luigiwalser <luigiwalser> 1:20140805.00-1.mga5
+ Revision: 664502
- new certdata.txt file as of 20140805

* Fri Jul 11 2014 luigiwalser <luigiwalser> 1:20140703.00-1.mga5
+ Revision: 651189
- new certdata.txt file as of 20140703

* Thu May 08 2014 oden <oden> 1:20140507.00-1.mga5
+ Revision: 621138
- new certdata.txt file as of 20140507

* Wed Mar 19 2014 oden <oden> 1:20140318.00-1.mga5
+ Revision: 605584
- new certdata.txt file as of 20140318

* Tue Dec 10 2013 luigiwalser <luigiwalser> 1:20131204.00-1.mga4
+ Revision: 556204
- new certdata.txt file as of 2013-12-04

* Thu Nov 14 2013 luigiwalser <luigiwalser> 1:20131111.00-1.mga4
+ Revision: 551152
- new certdata.txt file as of 2013-11-11

* Mon Oct 21 2013 umeabot <umeabot> 1:20130411.00-2.mga4
+ Revision: 539097
- Mageia 4 Mass Rebuild

* Fri Oct 04 2013 luigiwalser <luigiwalser> 1:20130411.00-1.mga4
+ Revision: 491390
- update java BRs
+ oden <oden>
- new certdata.txt file as of 2013-04-11 since it now lives in mozilla hg

* Thu Jan 24 2013 fwang <fwang> 1:20121229.00-4.mga3
+ Revision: 392002
- update rpm group

* Mon Jan 14 2013 umeabot <umeabot> 1:20121229.00-3.mga3
+ Revision: 380402
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 oden <oden> 1:20121229.00-2.mga3
+ Revision: 343283
- bump release

* Tue Jan 08 2013 oden <oden> 1:20121229.00-1.mga3
+ Revision: 343219
- new certdata.txt file as of 2012/12/29 (fixes CVE-2013-0743)

* Mon Jan 07 2013 blino <blino> 1:20121018.00-2.mga3
+ Revision: 340430
- add a Debian/Ubuntu compat symlink for /etc/ssl/private/ as well

* Sat Oct 27 2012 luigiwalser <luigiwalser> 1:20121018.00-1.mga3
+ Revision: 310747
- update certdata.txt to 2012/10/18 version

* Mon Jul 02 2012 luigiwalser <luigiwalser> 1:20120628.00-1.mga3
+ Revision: 266580
- update certdata.txt to 2012/06/28 version

* Sun Feb 26 2012 luigiwalser <luigiwalser> 1:20120218.00-1.mga2
+ Revision: 215028
- update certdata.txt to 2012/02/18 version
- update certdata.txt to 2012/02/18 version

* Mon Dec 26 2011 dmorgan <dmorgan> 1:20111103.00-1.mga2
+ Revision: 187788
- New version 20111103

* Wed Aug 31 2011 dmorgan <dmorgan> 1:20110830.00-1.mga2
+ Revision: 137338
- Remove P3: unneeded
- new certdata.txt file (fixes MFSA 2011-34 Protection against fraudulent DigiNotar certificates)
- Fix sha1.lst

* Wed Apr 20 2011 pterjan <pterjan> 1:20110323.00-1.mga1
+ Revision: 89070
- Update certdata.txt to 23/03/2011 version

* Sat Jan 15 2011 wally <wally> 1:20101202.00-2.mga1
+ Revision: 18895
- fix unwanted occurrences
- rename patch

* Thu Jan 13 2011 pterjan <pterjan> 1:20101202.00-1.mga1
+ Revision: 16347
- Drop obsolete tests
- imported package rootcerts


* Sat Dec 25 2010 Oden Eriksson <oeriksson@mandriva.com> 1:20101202.00-1mdv2011.0
+ Revision: 624972
- new certdata.txt file from upstream cvs (20101202)

* Thu Nov 25 2010 Oden Eriksson <oeriksson@mandriva.com> 1:20101119.00-1mdv2011.0
+ Revision: 601001
- new certdata.txt from upstream (2010-11-19)

* Thu Sep 09 2010 Oden Eriksson <oeriksson@mandriva.com> 1:20100827.00-1mdv2011.0
+ Revision: 576922
- new certdata.txt file as of 2010/08/27

* Mon May 17 2010 Oden Eriksson <oeriksson@mandriva.com> 1:20100408.00-1mdv2010.1
+ Revision: 544960
- drop the RSA Security 1024 V3 Root cert

* Tue Apr 06 2010 Oden Eriksson <oeriksson@mandriva.com> 1:20100403.01-1mdv2010.1
+ Revision: 532249
- new certdata.txt from upstream (20100403)

* Fri Mar 12 2010 Oden Eriksson <oeriksson@mandriva.com> 1:20100216.01-1mdv2010.1
+ Revision: 518349
- fix #58107 (provide compatibility symlink for Adobe Flash)
- new certdata.txt (20100216) from upstream

* Wed Feb 03 2010 Oden Eriksson <oeriksson@mandriva.com> 1:20091203.04-1mdv2010.1
+ Revision: 500052
- P3: remove the offending MD5 Collisions Forged Rogue CA 25c3 cert

* Thu Jan 28 2010 Oden Eriksson <oeriksson@mandriva.com> 1:20091203.03-1mdv2010.1
+ Revision: 497698
- avoid making useless (empty) debug packages

* Thu Jan 28 2010 Oden Eriksson <oeriksson@mandriva.com> 1:20091203.02-1mdv2010.1
+ Revision: 497654
- fix the bcond stuff (thanks anssi)

* Thu Jan 28 2010 Oden Eriksson <oeriksson@mandriva.com> 1:20091203.01-1mdv2010.1
+ Revision: 497593
- disable java cert generations on older products

* Sun Jan 24 2010 Oden Eriksson <oeriksson@mandriva.com> 1:20091203.00-1mdv2010.1
+ Revision: 495449
- new certdata.txt file as of 2009/12/03
- the java certs won't build unless using a safe locale

* Mon Oct 19 2009 Anssi Hannula <anssi@mandriva.org> 1:20090831.00-1mdv2010.0
+ Revision: 458242
- add multiple "-alt" suffixes to java certificate shortnames if more
  than 2 certificates share the same name
  (cacerts-rename-duplicates.patch modified)

  + Oden Eriksson <oeriksson@mandriva.com>
    - new certdata.txt from mozilla

* Mon Sep 28 2009 Olivier Blin <oblin@mandriva.com> 1:20090814.00-2mdv2010.0
+ Revision: 450336
- disable java on mips & arm, implying it's not noarch anymore
  (from Arnaud Patard)

* Sat Aug 22 2009 Oden Eriksson <oeriksson@mandriva.com> 1:20090814.00-1mdv2010.0
+ Revision: 419733
- new snapshot (20090814)

* Sun Aug 02 2009 Oden Eriksson <oeriksson@mandriva.com> 1:20090521.00-1mdv2010.0
+ Revision: 407545
- new cvs snap (20090521)
- the IGC/A cert was added upstream (S5)

* Mon Mar 23 2009 Anssi Hannula <anssi@mandriva.org> 1:20090115.00-1mdv2009.1
+ Revision: 360711
- java: rename identically named certificates that are not handled by
  mandriva.patch

  + Oden Eriksson <oeriksson@mandriva.com>
    - new certdata.txt file

* Sat Jan 24 2009 Oden Eriksson <oeriksson@mandriva.com> 1:20081017.00-2mdv2009.1
+ Revision: 333321
- roll back the certdata.txt file for now
- new certdata.txt file

* Fri Oct 24 2008 Oden Eriksson <oeriksson@mandriva.com> 1:20081017.00-1mdv2009.1
+ Revision: 296928
- new S1

* Sat Jul 05 2008 Anssi Hannula <anssi@mandriva.org> 1:20080503.00-2mdv2009.0
+ Revision: 232015
- add java subpackage that contains cacerts file for JRE, and a
  --with[out] java build option to disable it

* Fri Jul 04 2008 Oden Eriksson <oeriksson@mandriva.com> 1:20080503.00-1mdv2009.0
+ Revision: 231658
- new certdata.txt

* Wed Jun 18 2008 Thierry Vignaud <tv@mandriva.org> 1:20080117.00-2mdv2009.0
+ Revision: 225323
- rebuild

* Thu Feb 14 2008 Oden Eriksson <oeriksson@mandriva.com> 1:20080117.00-1mdv2008.1
+ Revision: 168072
- new certdata.txt (Guenter Knauf)

* Thu Dec 20 2007 Oden Eriksson <oeriksson@mandriva.com> 1:20070713.00-1mdv2008.1
+ Revision: 135400
- new S1 from upstream cvs

* Mon Dec 17 2007 Thierry Vignaud <tv@mandriva.org> 1:20070402.00-1mdv2008.1
+ Revision: 126645
- kill re-definition of %%buildroot on Pixel's request


* Tue Apr 03 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 20070402.00-1mdv2007.1
+ Revision: 150441
- Improve package versioning:
  - Fix version in order to point to current date.
  - Bumped epoch to 0 for this.
  - Ignores rpm's release, in order to avoid distro tags.
  - More details, please refer to comments on the package.

* Tue Apr 03 2007 Oden Eriksson <oeriksson@mandriva.com> 20071031-3mdv2007.1
+ Revision: 150288
- added the IGC/A CA root cert (French government CA)

* Wed Mar 21 2007 Andreas Hasenack <andreas@mandriva.com> 20071031-2mdv2007.1
+ Revision: 147526
- added a new verisign certificate (#29612)
- note to self: the mozilla/nss part of this package is not
  working as intended

* Tue Oct 31 2006 Oden Eriksson <oeriksson@mandriva.com> 20071031-1mdv2007.1
+ Revision: 74824
- new certdata.txt version
- bunzip sources
- import rootcerts-20060621-2mdv2007.0

* Thu Jun 22 2006 Oden Eriksson <oeriksson@mandriva.com> 20060621-2mdv2007.0
- added the cacert root cert
- add the certdata.txt to the package

* Thu Jun 22 2006 Oden Eriksson <oeriksson@mandriva.com> 20060621-1mdv2007.0
- new certdata.txt from the mozilla cvs

* Fri Nov 11 2005 Oden Eriksson <oeriksson@mandriva.com> 20051111-1mdk
- initial Mandriva package
- added ICP-Brasil from a patch added to our mozilla-firefox
- credits goes to Scott Grayban for finding this bug

